telemetry

package module
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 4, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

const SCHEMA_URL = "https://opentelemetry.io/schemas/1.26.0"

SCHEMA_URL holds the schema definition for attributes and resources.

Variables

This section is empty.

Functions

func NewMeterProvider

func NewMeterProvider(ctx context.Context, cfg MeterConfig) (metric.MeterProvider, error)

NewMeterProvider creates and returns a MeterProvider based on the provided config. This is the main entry point to set up telemetry in your services.

Types

type MeterConfig

type MeterConfig struct {
	Endpoint       string
	Insecure       bool
	ExportInterval time.Duration
}

MeterConfig includes any parameters you want to allow callers to override when creating a MeterProvider.

Directories

Path Synopsis

Jump to